# A framework for Google Hangouts Chat Bot

[![Build Status](https://travis-ci.org/ciandt/google_hangouts_chat_bot.svg?branch=master)](https://travis-ci.org/ciandt/google-hangouts-chat-bot)
[![Current version at PyPI](https://img.shields.io/pypi/v/google_hangouts_chat_bot.svg)](https://pypi.python.org/pypi/google_hangouts_chat_bot)
![Supported Python Versions](https://img.shields.io/pypi/pyversions/google_hangouts_chat_bot.svg)
![PyPI status](https://img.shields.io/pypi/status/google_hangouts_chat_bot.svg)
[![License: MIT](https://img.shields.io/pypi/l/google_hangouts_chat_bot.svg)](https://github.com/ciandt/google-hangouts-chat-bot/blob/master/LICENSE)

This is a framework you can use to build bots for Google Hangouts Chat.
It was made to be simple and extensible.

### What it does?

- TODO


## Installing

You can install using [pip](https://pip.pypa.io/en/stable/):

```
$ pip install google_hangouts_chat_bot
```


## Authors

- [@jeanpimentel](https://github.com/jeanpimentel) (Jean Pimentel)


## Contributing

Contributions are always welcome and highly encouraged.
See [CONTRIBUTING](CONTRIBUTING.md) for more information on how to get started.


## License

MIT - See [the LICENSE](LICENSE) for more information.
